@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "keymap-utils" "4.1.2"
+(define-package "keymap-utils" "20251011.1822"
   "Keymap utilities."
   '((emacs  "28.1")
     (compat "30.1"))
   :url "https://github.com/tarsius/keymap-utils"
-  :commit "a3c94ce2c191eb990f9789456b82bf4870af04a0"
-  :revdesc "v4.1.2-0-ga3c94ce2c191"
+  :commit "d0e5672aba7f3482414c1a87003de3d87b2cab5c"
+  :revdesc "d0e5672aba7f"
   :keywords '("convenience" "extensions")
   :authors '(("Jonas Bernoulli" . "emacs.keymap-utils@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.keymap-utils@jonas.bernoulli.dev")))
